#!/usr/bin/python
#
# The base classe for Ganglia news journalists.
#
# @Copyright@
# 
# 				Rocks
# 		         www.rocksclusters.org
# 			     Version 3.2.0
# 
# Copyright (c) 2004 The Regents of the University of California. All
# rights reserved.
# 
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
# 
# 1. Redistributions of source code must retain the above copyright
# notice, this list of conditions and the following disclaimer.
# 
# 2. Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution.
# 
# 3. All advertising materials mentioning features or use of this
# software must display the following acknowledgement: This product
# includes software developed by the ROCKS CLUSTER GROUP at the San
# Diego Supercomputer Center and its contributors.
# 
# 4. Neither the name of the Center nor the names of its contributors
# may be used to endorse or promote products derived from this software
# without specific prior written permission.
# 
# THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS''
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
# PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS
# BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
# BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
# WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
# OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
# IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
# 
# @Copyright@
#
# $Log: journalist.py,v $
# Revision 1.2  2004/04/14 22:01:49  fds
# Less verbose, quoting special chars in cluster name. New full-disk
# journalist inspired by lodestone.
#
# Revision 1.1  2004/04/13 20:16:05  fds
# The Ganglia RSS news prototype. 2 journalsits: MIA and load.
#
#

import os
import sys
import syslog
import time
import urllib


class Journalist:
	"""The base class for all ganglia news collectors."""

	def __init__(self, app):
		self.app = app
		
		self.today = time.strftime("%d-%b")

	def name(self):
		"""The name of a Ganglia Journalist"""
		return self.__class__.__name__

	def run(self):
		pass
		
	def getGanglia(self):
		return self.app.ganglia

	def getTime(self):
		return self.app.getTime()
		
	def getLocalTime(self):
		return self.app.getLocalTime()

	def getDate(self):
		return self.today

	def getHostPage(self, cluster, host, physical=0):
		"Gives a URL to a Ganglia Host page."

		link = '%s/ganglia/?c=%s&amp;h=%s' \
			% (cluster.getUrl(), 
			urllib.quote(cluster.getName()), 
			host.getName())

		if physical:
			link += '&amp;p=1'

		return link
		

	def debug(self, msg):
		mesg = "gevent debug: %s" % (msg)
		syslog.syslog(mesg)
		print mesg

	def info(self,msg):
		mesg = "gevent info: %s" % (msg)
		syslog.syslog(mesg)
		print mesg

	def warning(self, msg):
		mesg = "gevent warning: %s" % (msg)
		syslog.syslog(syslog.LOG_WARNING, mesg)
		print mesg
		
		
	def uptime(self, seconds):
		"""Returns a nicely formatted time from a seconds figure."""
	
		try: 
			secs = int(seconds)
		except:
			return ''

		days = secs/86400
		if days:
			secs = secs % (days*86400)
		hours = secs/3600
		if hours:
			secs = secs % (hours*3600)
		mins = secs/60
		if mins:
			secs = secs % (mins*60)

		s = ''
		if days != 1:
			s = 's'
		if days > 0:
			return "%s day%s, %s:%s:%s" % \
				(days, s, hours, mins, secs)
		else:
			return "%s:%s:%s" % (hours,mins,secs)


	def recordItem(self, itemname, item):
		"""Places an RSS snippet of an item in the appropriate
		place in the filesystem."""

		year, month, day = self.getLocalTime()[:3]

		# We want one item per host, per month, per journalist.

		todaysNews = os.path.join(self.app.basedir, 
			"%s" % year,
			"%02d" % month,
			self.name())

		os.system('mkdir -p %s' % todaysNews)

		i = open(os.path.join(todaysNews, "%s.rss" % itemname), 'w')
		i.write(item)
		i.close()

